<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Graphics.Printing.PrintSupport

Windows Runtime (WinRT) APIs for for the `Windows.Graphics.Printing.PrintSupport` namespace.

This package provides the `winrt.windows.graphics.printing.printsupport` module.
